const std = @import("std");
const Allocator = std.mem.Allocator;
const List = std.ArrayList;
const Map = std.AutoHashMap;
const StrMap = std.StringHashMap;
const BitSet = std.DynamicBitSet;

const util = @import("util.zig");
const gpa = util.gpa;

const data = @embedFile("data/day01.txt");
const data2 = @embedFile("data/day01_part2.txt");

pub fn main() !void {
    const allocator = std.heap.page_allocator;

    try part01(allocator, data);
}

fn find_first_digit_number(word: []const u8) !u8 {
    var i: usize = 0;

    while (i < word.len) : (i += 1) {
        if (std.ascii.isDigit(word[i])) {
            return word[i];
        }
    }

    return word[i];
}

fn find_last_digit_number(word: []const u8) !u8 {
    var i: usize = word.len - 1;

    while (i < word.len) : (i -= 1) {
        if (std.ascii.isDigit(word[i])) {
            std.debug.print("last {}\n", .{word[i]});
            return word[i];
        }
    }

    return word[i];
}

fn part01(allocator: std.mem.Allocator, day01: []const u8) !void {
    var splits = std.mem.split(u8, day01, "\n");
    var total: u32 = 0;
    while (splits.next()) |line| {
        if (line.len <= 0) {
            continue;
        }

        std.debug.print("Line: {s}\n", .{line});
        const first_digit_char = try find_first_digit_number(line);
        const last_digit_char = try find_last_digit_number(line);

        const first_and_last = try std.fmt.allocPrint(allocator, "{c}{c}", .{ first_digit_char, last_digit_char });

        std.debug.print("{c} + {c}\n", .{ first_digit_char, last_digit_char });
        var digits: u32 = 0;
        digits = try std.fmt.parseInt(u32, first_and_last, 10);
        total += digits;
    }

    std.debug.print("First Total: {d}\n", .{total});
}

// Useful stdlib functions
const tokenizeAny = std.mem.tokenizeAny;
const tokenizeSeq = std.mem.tokenizeSequence;
const tokenizeSca = std.mem.tokenizeScalar;
const splitAny = std.mem.splitAny;
const splitSeq = std.mem.splitSequence;
const splitSca = std.mem.splitScalar;
const indexOf = std.mem.indexOfScalar;
const indexOfAny = std.mem.indexOfAny;
const indexOfStr = std.mem.indexOfPosLinear;
const lastIndexOf = std.mem.lastIndexOfScalar;
const lastIndexOfAny = std.mem.lastIndexOfAny;
const lastIndexOfStr = std.mem.lastIndexOfLinear;
const trim = std.mem.trim;
const sliceMin = std.mem.min;
const sliceMax = std.mem.max;

const parseInt = std.fmt.parseInt;
const parseFloat = std.fmt.parseFloat;

const print = std.debug.print;
const assert = std.debug.assert;

const sort = std.sort.block;
const asc = std.sort.asc;
const desc = std.sort.desc;

// Generated from template/template.zig.
// Run `zig build generate` to update.
// Only unmodified days will be updated.
